@@ -1,5 +1,5 @@
 #
-# Copyright John Reid 2010
+# Copyright John Reid 2010, 2012
 #
 
 """
@@ -9,7 +9,8 @@ Stores filenames for test data and potential starting seeds for each data set.
 import os
 from cookbook.cache_decorator import cachedmethod
 
-fasta_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), '..', '..', 'python', 'test', 'fasta'))
+from pkg_resources import resource_filename
+fasta_dir = resource_filename('stempy', 'test/fasta')
 
 
 data_sets = [
